﻿local addonName, addonData = ...;

-- The frames we will use 
addonData["Frames"] = addonData["Frames"] or {};
addonData["Frames"].SWF_EventFrame = nil;
addonData["Frames"].SWF_WatchFrame = nil;
addonData["Frames"].SWF_InfoPanel = nil;

-- Reset the default WatchFrame so that we have control
local function ResetWatchFrame(parent)

	if ( addonData["nUI"].IsLoaded() ) then
		nUI_Movers:lockFrame( WatchFrame, false, nil ); 
		nUI_Options.movedWatchFrame = true;
	end

	addonData["WatchFrame"].ResetWatchFrame(parent);
	
end

-- Create the Scrollable Frame
local function CreateScrollFrame()

	if ( addonData["nUI"].IsLoaded() ) then
		nUI_Movers:lockFrame( WatchFrame, false, nil );
		nUI_Options.movedWatchFrame = true;
	end
	
	local f = addonData["ScrollFrame"].Create("SWF_WatchFrame");

	hooksecurefunc( "WatchFrame_Collapse", function(self)
		if ( addonData["nUI"].Loaded and addonData["nUI"].InfoPanel ) then
			-- Don't do anything extra if docked
		else
			addonData["WatchFrame"].CollapseExpand(self); 
			f:SetHeight(40);
			f:SetWidth(160);
			f.Child:SetHeight( 2 );
			f.ScrollBar:Hide();
			f:ClearAllPoints();
			addonData["ScrollFrame"].SetAnchor(f);	
		end
	end);

	hooksecurefunc( "WatchFrame_Expand", function(self) 
		if ( addonData["nUI"].Loaded and addonData["nUI"].InfoPanel ) then 
			-- Don't do anything extra if docked
		else
			addonData["WatchFrame"].CollapseExpand(self); 
			addonData["ScrollFrame"].Resize(f);			
			f.Child:SetHeight(addonData["ScrollFrame"].ScrollSize);
			f:ClearAllPoints();
			addonData["ScrollFrame"].SetAnchor(f);		
		end
	end);

	addonData["ScrollFrame"].UseAnchor = addonData["WatchFrame"].UseAnchor;

	ResetWatchFrame( f.Child );
			
	-- Handle the Collapse/Expand Button
	local b = WatchFrameCollapseExpandButton;
	b:SetParent(f)
	b:ClearAllPoints();
	b:SetPoint("TOPRIGHT",f,"TOPRIGHT",-30,-10);
	b.Hide = function() end

	-- Handle the Title
	local t = WatchFrameTitle;
	t:SetParent(f)
	t:ClearAllPoints();
	t:SetPoint("TOPLEFT",f,"TOPLEFT",30,-10);
	t:SetPoint("TOPRIGHT",b,"TOPLEFT",-5,0);
	t.Hide = function() end
	
	-- Because we are moving the Title and Button out of the watch frame, move the scroll frame down
	f.Scroll:ClearAllPoints();
	f.Scroll:SetPoint("LEFT",f, "LEFT", 10, 0 );
	f.Scroll:SetPoint("TOP",b,"BOTTOM",0,-5);
	f.Scroll:SetPoint( "BOTTOMRIGHT", -30, 7.5 );
	
	-- Because we have taken the Title and Button out of the watch frame we should now have more room 
	-- for the watchframe lines themselves so expand them to fill the space
	local w = WatchFrameLines;
	w:ClearAllPoints();
	w:SetAllPoints();
	
	return f;
end

local function onEvent()
	if event == "VARIABLES_LOADED" then

		SLASH_ScrollingWatchFrameCmd1 = '/swf';
		SlashCmdList['ScrollingWatchFrameCmd'] = addonData["SlashCmds"].Validate;
	
		if ( addonData["nUI"].IsLoaded() and addonData["nUI"].UseInfoPanel() ) then 

			-- We don't want nUI to play with the WatchFrame, no offense, honest
			nUI_ResetWatchFrame = function() end;

			-- Create the Frame that the InfoPanel will be parenting
			addonData["Frames"].SWF_WatchFrame = CreateScrollFrame();

			-- If this was successful ( and it darn well should be ) then Create the InfoPanel
			if ( addonData["Frames"].SWF_WatchFrame and not addonData["Frames"].SWF_InfoPanel ) then 
				addonData["Frames"].SWF_InfoPanel = addonData["nUI"].CreateInfoPanel(	addonData["Frames"].SWF_WatchFrame, 23, "SWF_InfoPanel", addonData["ScrollFrame"].IsMovable() );
			end
		end

	elseif event == "PLAYER_ENTERING_WORLD" then	

		if ( addonData["nUI"].IsLoaded() ) then
			nUI_ResetWatchFrame = function() end;
		end

		
		if ( not addonData["Frames"].SWF_InfoPanel and not addonData["Frames"].SWF_WatchFrame ) then
			addonData["Frames"].SWF_WatchFrame = CreateScrollFrame();
		end
		
		addonData["Frames"].SWF_EventFrame:UnregisterEvent( "PLAYER_ENTERING_WORLD" );
	end	
end

addonData["Frames"].SWF_EventFrame    = CreateFrame( "Frame", "SWF_EventFrame", UIParent );
addonData["Frames"].SWF_EventFrame:SetScript( "OnEvent", onEvent );
addonData["Frames"].SWF_EventFrame:RegisterEvent( "PLAYER_ENTERING_WORLD" );
addonData["Frames"].SWF_EventFrame:RegisterEvent( "VARIABLES_LOADED" );

