
local addonName, addonData = ...;

addonData["SlashCmds"] = {};

addonData["SlashCmds"].Reset = false;

addonData["SlashCmds"].Update = function()

	if ( addonData["nUI"].Loaded and addonData["nUI"].InfoPanel ) then
		-- We are in InfoPanel docked mode and shouldn't be resized or anchored or moved as the InfoPanel system deals with that.
		addonData["Frames"].SWF_InfoPanel.setBackDrop();
	else
		-- Resize and store the current anchor setting
		addonData["ScrollFrame"].Resize(addonData["Frames"].SWF_WatchFrame);
		addonData["ScrollFrame"].StoreAnchor(addonData["Frames"].SWF_WatchFrame);
		-- Set new Backdrop and movability settings based on docked status
		addonData["ScrollFrame"].SetBackDrop(addonData["Frames"].SWF_WatchFrame);
		addonData["ScrollFrame"].SetMovable(addonData["Frames"].SWF_WatchFrame);
	end
	
	-- Check that we are in the right collapse state
	addonData["WatchFrame"].RestoreWatchFrame();
	
	addonData["Frames"].SWF_WatchFrame.Child:SetHeight(addonData["ScrollFrame"].ScrollSize);
	
	-- If the Scroll Size is less than the frame itself then hide the scrollbar as there is nothing to scroll
	if ( addonData["ScrollFrame"].ScrollSize > addonData["Frames"].SWF_WatchFrame:GetHeight() ) then
		addonData["Frames"].SWF_WatchFrame.ScrollBar:Show();
	else
		addonData["Frames"].SWF_WatchFrame.ScrollBar:Hide();
	end

	-- We changed some details so update the saved variables
	addonData["SavedVars"].Save();
	addonData["SlashCmds"].Reset = false;
end

addonData["SlashCmds"].Validate = function (msg)

        msg = string.lower(msg);
		local args = {};
		for word in string.gmatch(msg,"[^%s]+") do
			table.insert(args,word);
		end
		DefaultsChanged = false;
		
		-- Reset the Saved Variables to their programmed defaults --
		if ( args[1] == "reset" ) then
			local oldIP = addonData["nUI"].InfoPanel;
			addonData["SavedVars"].Reset();			
			addonData["SavedVars"].Save();
			local newIP = addonData["nUI"].InfoPanel;
			if ( oldIP ~= newIP ) then 
				ReloadUI(); 
			else
				addonData["SlashCmds"].Reset = true;
				DefaultsChanged = true;
			end
			
		-- Dock the Scrolling Watch Frame into an Info Panel
		elseif ( args[1] == "dock" ) then
			if ( addonData["nUI"].Loaded ) then
				addonData["nUI"].InfoPanel = not addonData["nUI"].InfoPanel;
				addonData["SavedVars"].Save();
				ReloadUI();
			else
				DEFAULT_CHAT_FRAME:AddMessage("Only nUI Users can use the docking facility.");
			end
		
		-- Toggle the movability of the Scrolling Watch Frame
		elseif ( args[1] == "lock" ) then
			if ( addonData["nUI"].Loaded and addonData["nUI"].InfoPanel ) then
				-- This particular addon is problematic if movable but small enough to not need moving so keep it locked.
				DEFAULT_CHAT_FRAME:AddMessage("nUI Users cannot toggle the lock ability of the scrolling frame.");
			else
				addonData["ScrollFrame"].Movable = not addonData["ScrollFrame"].Movable;
				if ( addonData["ScrollFrame"].IsMovable() ) then
					DEFAULT_CHAT_FRAME:AddMessage("The Scrolling Watch Frame has been unlocked.");
				else
					DEFAULT_CHAT_FRAME:AddMessage("The Scrolling Watch Frame has now been locked.");
				end
				DefaultsChanged = true;
			end
			
		-- Set the width of the Scrolling Watch Frame
		elseif ( args[1] == "width" ) then
			if ( addonData["nUI"].InfoPanel ) then
				DEFAULT_CHAT_FRAME:AddMessage("Width can only be adjusted while not in InfoPanel mode");
			else
				if ( args[2] and tonumber(args[2]) >= 300 and tonumber(args[2]) <= 600) then
					addonData["ScrollFrame"].Width = tonumber(args[2]);
					print("The Scrolling Watch Frame now has a width of ", addonData["ScrollFrame"].Width);
					DefaultsChanged = true;
				else
					if ( args[2] ) then
						DEFAULT_CHAT_FRAME:AddMessage("Please use a number between 300 and 600.");
					else
						DEFAULT_CHAT_FRAME:AddMessage("Please use the command /swf width x where x is a number between 300 and 600.");
					end
					print("The current width of the Scrolling Watch Frame is : ", addonData["ScrollFrame"].Width);
				end
			end
			
		-- Set the height of the Scrolling Watch Frame
		elseif ( args[1] == "height" ) then
			if ( addonData["nUI"].InfoPanel ) then
				DEFAULT_CHAT_FRAME:AddMessage("Height can only be adjusted while not in InfoPanel mode");
			else
				if ( args[2] and tonumber(args[2]) >= 100 and tonumber(args[2]) <= 800) then
					addonData["ScrollFrame"].Height = tonumber(args[2]);
					print("The Scrolling Watch Frame now has a height of ", addonData["ScrollFrame"].Height);
					DefaultsChanged = true;
				else
					if ( args[2] ) then
						DEFAULT_CHAT_FRAME:AddMessage("Please use a number between 100 and 800.");
					else
						DEFAULT_CHAT_FRAME:AddMessage("Please use the command /swf height x where x is a number between 100 and 800.");
					end
					print("The current height of the Scrolling Watch Frame is : ", addonData["ScrollFrame"].Height);
				end
			end
			
		-- Set the size of the scroll child
		elseif ( args[1] == "scroll" ) then
			if ( args[2] and tonumber(args[2]) >= 100 and tonumber(args[2]) <= 5000) then
				addonData["ScrollFrame"].ScrollSize = tonumber(args[2]);
				print("The Scrolling Watch Frame now has a scrollable window height of ", addonData["ScrollFrame"].ScrollSize);
				DefaultsChanged = true;
			else
				if ( args[2] ) then
					DEFAULT_CHAT_FRAME:AddMessage("Please use a number between 100 and 5000.");
				else
					DEFAULT_CHAT_FRAME:AddMessage("Please use the command /swf scroll x where x is a number between 100 and 5000.");
				end
				print("The current value for the scroll size is : ", addonData["ScrollFrame"].ScrollSize);
			end
			
		-- Toggles the background display option
		elseif ( args[1] == "background" ) then
			local enabled = nil;
			if ( addonData["nUI"].Loaded and addonData["nUI"].InfoPanel ) then
				addonData["nUI"].BackGround.Enabled = not addonData["nUI"].BackGround.Enabled;
				enabled = addonData["nUI"].BackGround.Enabled;
			else
				addonData["ScrollFrame"].BackGround.Enabled = not addonData["ScrollFrame"].BackGround.Enabled;
				enabled = addonData["ScrollFrame"].BackGround.Enabled;
			end
			if ( enabled ) then
				DEFAULT_CHAT_FRAME:AddMessage("The Scrolling Watch Frame whilst in the current dock status will now have a background");
			else
				DEFAULT_CHAT_FRAME:AddMessage("The Scrolling Watch Frame whilst in the current dock status will not have a background");
			end
			DefaultsChanged = true;
			
		-- Toggles the ability to store multiple anchors ( main, collapsed, expanded ), main will be used if not using multiple anchors
		elseif ( args[1] == "multiple" ) then
			if ( addonData["nUI"].Loaded and addonData["nUI"].InfoPanel ) then
				-- Seeing as the infopanel will not be movable, no need for multiple anchors
				DEFAULT_CHAT_FRAME:AddMessage("nUI Users have no need of multiple anchors.");
			else
				addonData["WatchFrame"].MultipleAnchors = not addonData["WatchFrame"].MultipleAnchors;
				if ( addonData["WatchFrame"].MultipleAnchors ) then
					DEFAULT_CHAT_FRAME:AddMessage("The Scrolling Watch Frame will now track and use the collapsed and expanded versions of its anchors.");
				else
					DEFAULT_CHAT_FRAME:AddMessage("The Scrolling Watch Frame will now only track the main anchor.");
				end
				DEFAULT_CHAT_FRAME:AddMessage("The current position will be updated accordingly.");
				DefaultsChanged = true;	
			end
			
		-- Display the slash commands
		else
			DEFAULT_CHAT_FRAME:AddMessage("Slash Commands Available");
			DEFAULT_CHAT_FRAME:AddMessage("========================");
			DEFAULT_CHAT_FRAME:AddMessage("|cFFFFFF00reset|r - Resets the Saved Variables to their defaults.  This will result in a reloadUI call.");
			DEFAULT_CHAT_FRAME:AddMessage("|cFFFFFF00dock|r - nUI users can toggle the scrolling frame into an InfoPanel.  This will result in a reloadUI call.");
			DEFAULT_CHAT_FRAME:AddMessage("|cFFFFFF00lock|r - toggles the movability flag of the scrolling frame when not in an InfoPanel.");
			DEFAULT_CHAT_FRAME:AddMessage("|cFFFFFF00background|r - will toggle the background for the scrolling frame in the current docking mode.");
			DEFAULT_CHAT_FRAME:AddMessage("|cFFFFFF00multiple|r - will toggle the ability to track both a collapsed mode anchor and an expanded mode anchor when not in an InfoPanel.");
			DEFAULT_CHAT_FRAME:AddMessage("|cFFFFFF00width x|r - will set the width of the scrolling frame while not in an Info Panel to x ( 100 - 600 ).");
			DEFAULT_CHAT_FRAME:AddMessage("|cFFFFFF00height x|r - will set the height of the scrolling frame while not in an Info Panel to x ( 100 - 800 ).");
			DEFAULT_CHAT_FRAME:AddMessage("|cFFFFFF00scroll x|r - will set the height of the scrolling area to x ( 100 - 3000 ).");
			DEFAULT_CHAT_FRAME:AddMessage("==========================");
			DEFAULT_CHAT_FRAME:AddMessage("Current Values are as follows, dependant on the docked status of the frame :");
			print("Docked with InfoPanel system for when nUI is active ? ", addonData["nUI"].InfoPanel);
			print("Locked ? [Docked] N/A [UnDocked] ", addonData["ScrollFrame"].IsMovable() );
			print("Multiple Anchor Points ? [Docked] N/A [UnDocked] ", addonData["WatchFrame"].MultipleAnchors );
			print("Has a BackGround ? [Docked] ", addonData["nUI"].BackGround.Enabled, " [UnDocked] ", addonData["ScrollFrame"].BackGround.Enabled);
			print("Current Width ? [Docked] N/A [UnDocked] ",addonData["ScrollFrame"].Width );
			print("Current Height ? [Docked] N/A [UnDocked] ",addonData["ScrollFrame"].Height );
			print("Current Scroll Size ? ", addonData["ScrollFrame"].ScrollSize);

		end
		
		-- If something has been changed, update the frame.  Anything major would have had a reload.
		if ( DefaultsChanged ) then addonData["SlashCmds"].Update(); end
end
