local addonName, addonData = ...;

addonData["ScrollFrame"] = {};

addonData["ScrollFrame"].Frame = nil;
addonData["ScrollFrame"].Resizable = true;
addonData["ScrollFrame"].Movable = true;
addonData["ScrollFrame"].ScrollSize = 1000;
addonData["ScrollFrame"].Width = 300;
addonData["ScrollFrame"].Height = 200;

addonData["ScrollFrame"].MainAnchor = { 
	Offset = { Top = 0, Left = 0 } 
};

-- Variables for the InfoPanel BackGround
addonData["ScrollFrame"].BackGround = {
	Enabled = true,
	BackDrop = {       
		bgFile = "Interface/Tooltips/UI-Tooltip-Background", 
		edgeFile = "Interface/Tooltips/UI-Tooltip-Border", 
		tile = true, 
		tileSize = 16, 
		edgeSize = 16, 
		insets = { left = 4, right = 4, top = 4, bottom = 4 }
	},                       
	BackColor = { red=0,green=0,blue=0,alpha=1 },
	BorderColor = { red=255,green=255,blue=0,alpha=1 }
};

addonData["ScrollFrame"].SetBackDrop = function (self)
	local bd = addonData["ScrollFrame"].BackGround.BackDrop;
	local bg = addonData["ScrollFrame"].BackGround.BackColor;
	local bc = addonData["ScrollFrame"].BackGround.BorderColor;
	if ( not addonData["ScrollFrame"].BackGround.Enabled ) then
		bd = nil;
		bg = { 0,0,0,0 };
		bc = { 0,0,0,0 };
	end
	self:SetBackdrop(bd);
	self:SetBackdropColor(bg.red,bg.green,bg.blue, bg.alpha);
	self:SetBackdropBorderColor(bc.red, bc.green,bc.blue, bc.alpha);	
end

addonData["ScrollFrame"].IsResizable = function(isResizable)
	if ( isResizable ~= nil ) then
		addonData["ScrollFrame"].Resizable = isResizable;
	end
	return addonData["ScrollFrame"].Resizable;
end

addonData["ScrollFrame"].Resize = function(self)
	if ( addonData["ScrollFrame"].IsResizable() ) then
		self:SetWidth(addonData["ScrollFrame"].Width);
		self:SetHeight(addonData["ScrollFrame"].Height);

		if ( self.ScrollBar ) then
			-- If the Scroll Size is less than the frame itself then hide the scrollbar as there is nothing to scroll
			if ( addonData["ScrollFrame"].ScrollSize > self:GetHeight() ) then
				self.ScrollBar:Show();
			else
				self.ScrollBar:Hide();
			end
		end
		
	end
end

addonData["ScrollFrame"].UseAnchor = function()
	return addonData["ScrollFrame"].MainAnchor;
end

-- Set the Anchor to the Frame
addonData["ScrollFrame"].SetAnchor = function(self)
	if ( not self ) then return; end
	local result = addonData["ScrollFrame"].UseAnchor();
	local offset = addonData["ScrollFrame"].MainAnchor.Offset;
	if ( result ) then 	offset = result.Offset; end
	local pos = { pt = "TOPLEFT", a = UIParent, apt = "BOTTOMLEFT", x = offset.Left, y = offset.Top };
	if ( offset.Left == 0 and offset.Top == 0 ) then
		pos = { pt = "CENTER", a = UIParent, apt = "CENTER", x = offset.Left, y = offset.Top };
	end
	self:SetPoint(pos.pt, pos.a, pos.apt, pos.x, pos.y);
end
	
-- Get the Anchor to the Frame
addonData["ScrollFrame"].StoreAnchor = function(self)
	if ( not self ) then return; end
	local result = addonData["ScrollFrame"].UseAnchor();
	if ( not result ) then
		addonData["ScrollFrame"].MainAnchor.Offset.Top = self:GetTop();
		addonData["ScrollFrame"].MainAnchor.Offset.Left = self:GetLeft();
	else
		result.Offset.Top = self:GetTop();
		result.Offset.Left = self:GetLeft();
	end
	local offset = addonData["ScrollFrame"].MainAnchor.Offset;
	if ( result ) then 	offset = result.Offset; end
	local pos = { pt = "TOPLEFT", a = UIParent, apt = "BOTTOMLEFT", x = offset.Left, y = offset.Top };
	if ( offset.Left == 0 and offset.Top == 0 ) then
		pos = { pt = "CENTER", a = UIParent, apt = "CENTER", x = offset.Left, y = offset.Top };
	end
end
	
-- Handle OnMouseUp Event for the frame
addonData["ScrollFrame"].onMouseDown = function(self)
	if ( ( not self.isLocked ) or ( self.isLocked == 0 ) ) then
		self:StartMoving();
		self.isMoving = true;
		self.hasMoved = false;
	end
end

-- Respond to MouseUp events
addonData["ScrollFrame"].onMouseUp = function(self)
	if ( self.isMoving ) then
		self:StopMovingOrSizing();
		self.isMoving = false;
		self.hasMoved = true;
	end
	if ( self.hasMoved ) then
		addonData["ScrollFrame"].StoreAnchor(self);
	end
end
		
-- Respond to Hide Events
addonData["ScrollFrame"].onHide = function(self)
	if ( self.isMoving ) then
		self:StopMovingOrSizing();
		self.isMoving = false;
	end
end

addonData["ScrollFrame"].IsMovable = function(isMovable)
	if ( isMovable ~= nil ) then
		addonData["ScrollFrame"].Movable = isMovable;
	end
	return addonData["ScrollFrame"].Movable;
end

addonData["ScrollFrame"].SetMovable = function(self)
	if ( addonData["ScrollFrame"].IsMovable() ) then
		self:RegisterForDrag("LeftButton");
		self:EnableMouse(true);
		self:SetMovable(true);
		self:SetScript("OnMouseDown",addonData["ScrollFrame"].onMouseDown);
		self:SetScript("OnMouseUp",addonData["ScrollFrame"].onMouseUp);
		self:SetScript("OnHide",addonData["ScrollFrame"].onHide);
	else
		self:RegisterForDrag(nil);
		self:EnableMouse(false);
		self:SetMovable(false);
		self:SetScript("OnMouseDown",nil);
		self:SetScript("OnMouseUp",nil);
		self:SetScript("OnHide",nil);
	end		
end


addonData["ScrollFrame"].ScrollChild = function(name,parent)
    local c = CreateFrame( "Frame", name.."_ScrollChild", parent );
	c:SetHeight( addonData["ScrollFrame"].ScrollSize );
    c:SetWidth( parent:GetWidth() );
    c:SetAllPoints( parent );
    parent:SetScrollChild( c );
	return c;
end

addonData["ScrollFrame"].ScrollFrame = function(name,parent)
	local s = CreateFrame( "ScrollFrame", name.."_ScrollFrame", parent, "UIPanelScrollFrameTemplate" );
	local b = _G[s:GetName() .. "ScrollBar"];
    s:SetWidth( parent:GetWidth() - 35 );
	s:SetPoint( "TOPLEFT", 5, -7.5 );
	s:SetPoint( "BOTTOMRIGHT", -30, 7.5 );
	return s,b;
end

addonData["ScrollFrame"].Container = function(name,parent)
	local c = CreateFrame( "Frame", name.."_Container",parent);
	c:SetClampedToScreen(true);
	c:SetFrameStrata("HIGH");
	addonData["ScrollFrame"].Resize(c);
	addonData["ScrollFrame"].SetBackDrop(c);
	addonData["ScrollFrame"].SetMovable(c);
	addonData["ScrollFrame"].SetAnchor(c);
	addonData["ScrollFrame"].StoreAnchor(c);
	return c;
end

addonData["ScrollFrame"].Create = function(name)
	local f = addonData["ScrollFrame"].Container(name,UIParent);
	f.Scroll, f.ScrollBar = addonData["ScrollFrame"].ScrollFrame(name,f);
	f.Child = addonData["ScrollFrame"].ScrollChild(name,f.Scroll);
	
	-- If the Scroll Size is less than the frame itself then hide the scrollbar as there is nothing to scroll
	if ( addonData["ScrollFrame"].ScrollSize > f:GetHeight() ) then
		f.ScrollBar:Show();
	else
		f.ScrollBar:Hide();
	end
	
	return f;
end
