local addonName, addonData = ...;

local Translate = addonData.Localization;

addonData["nUI"] = {};

addonData["nUI"].Loaded = false;
addonData["nUI"].InfoPanel = false;
addonData["nUI"].Movable = false;

addonData["nUI"].IsLoaded = function()
	addonData["nUI"].Loaded = IsAddOnLoaded("nUI");
	return addonData["nUI"].Loaded;
end

addonData["nUI"].UseInfoPanel = function(value)	
	if ( value ~= nil ) then
		addonData["nUI"].InfoPanel = value;
	end
	return addonData["nUI"].InfoPanel;
end

addonData["nUI"].IsMovable = function(isMovable)
	if ( isMovable ~= nil ) then
		addonData["nUI"].Movable = isMovable;
	end
	return addonData["nUI"].Movable;
end

-- Variables for the InfoPanel BackGround
addonData["nUI"].BackGround = {
		Enabled = false,
		BackDrop = {       
			bgFile = "Interface/Tooltips/UI-Tooltip-Background", 
			edgeFile = "Interface/Tooltips/UI-Tooltip-Border", 
			tile = true, 
			tileSize = 16, 
			edgeSize = 16, 
			insets = { left = 4, right = 4, top = 4, bottom = 4 }
		},                       
		BackColor = { red=0,green=0,blue=0,alpha=1 },
		BorderColor = { red=255,green=255,blue=0,alpha=1 }
};

addonData["nUI"].CreateInfoPanel = function(child, id, name)

	local InfoPanel;
	
	-- No InfoPanels found yet?  Create the table ready for use then
	if not nUI_InfoPanels then nUI_InfoPanels = {}; end
			
	-- Set Up the Panel Values
	nUI_INFOMODE  = id;
	nUI_INFOPANEL = name;
			
	-- Set Up the Panel Data itself
	nUI_InfoPanels[nUI_INFOPANEL ] =
	{	
		enabled   = true,
		desc      = Translate["Info Panel Text"],             -- player friendly name/description of the panel
		label     = Translate["Info Panel Label"],	       -- label to use on the panel selection button face
		rotation  = nUI_INFOMODE,            -- index or position this panel appears on/in when clicking the selector button
		full_size = true;                              -- this plugin requires the entire info panel port without the button bag
		
		options  =
		{
			enabled  = true,
		},
	};
			
	InfoPanel    = CreateFrame( "Frame", nUI_INFOPANEL, nUI_Dashboard.Anchor );
	InfoPanel.active   = true;
		
	local function onEvent()
		if event == "VARIABLES_LOADED" then
			InfoPanel.active = true;
		end	
	end
	InfoPanel:SetScript( "OnEvent", onEvent );
	InfoPanel:RegisterEvent( "VARIABLES_LOADED" );

	---------------------------------------------------
	-- [v1.01.00] initPanel routine
	---------------------------------------------------
	InfoPanel.initPanel = function( container, options )
		InfoPanel.container = container;
		InfoPanel.options   = options;
		if options and options.enabled then
			InfoPanel.setEnabled( true );
		end
	end

	---------------------------------------------------
	-- [v1.01.00] sizeChanged routine
	---------------------------------------------------
	InfoPanel.sizeChanged = function( scale, height, width )
		local options  = InfoPanel.options;
		local plugin   = InfoPanel.plugin;
		InfoPanel.scale = scale;
	end	

	InfoPanel.setBackDrop = function ( )
		local plugin = InfoPanel.plugin;
		local bd = addonData["nUI"].BackGround.BackDrop;
		local bg = addonData["nUI"].BackGround.BackColor;
		local bc = addonData["nUI"].BackGround.BorderColor;
		if ( not addonData["nUI"].BackGround.Enabled ) then
			bd = nil;
			bg = { 0,0,0,0 };
			bc = { 0,0,0,0 };
		end
		plugin:SetBackdrop(bd);
		plugin:SetBackdropColor(bg.red,bg.green,bg.blue, bg.alpha);
		plugin:SetBackdropBorderColor(bc.red, bc.green,bc.blue, bc.alpha);	
	end

	InfoPanel.setMovable = function( )

		local plugin = InfoPanel.plugin;
	
		-- Respond to MouseDown events
		local onMouseDown = function(self)
			if ( ( not self.isLocked ) or ( self.isLocked == 0 ) ) then
				self:StartMoving();
				self.isMoving = true;
				self.hasMoved = false;
			end
		end
		
		-- Respond to MouseUp events
		local onMouseUp = function(self)
			if ( self.isMoving ) then
				self:StopMovingOrSizing();
				self.isMoving = false;
				self.hasMoved = true;
			end
		end
		
		-- Respond to Hide Events
		local onHide = function(self)
			if ( self.isMoving ) then
				self:StopMovingOrSizing();
				self.isMoving = false;
			end
		end
		
		if ( addonData["nUI"].IsMovable() ) then
			plugin:RegisterForDrag("LeftButton");
			plugin:EnableMouse(true);
			plugin:SetMovable(true);
			plugin:SetScript("OnMouseDown",onMouseDown);
			plugin:SetScript("OnMouseUp",onMouseUp);
			plugin:SetScript("OnHide",onHide);
		else
			plugin:RegisterForDrag(nil);
			plugin:EnableMouse(false);
			plugin:SetMovable(false);
			plugin:SetScript("OnMouseDown",nil);
			plugin:SetScript("OnMouseUp",nil);
			plugin:SetScript("OnHide",nil);
		end
		
	end
	
	InfoPanel.setAnchors = function()
		local plugin = child;
		plugin:ClearAllPoints();
		plugin:SetPoint( "BOTTOMRIGHT", InfoPanel.container, "BOTTOMRIGHT", 0, 0 );
		plugin:SetPoint( "TOPLEFT", InfoPanel.container, "TOPLEFT", 0, 0 );
	end
	
	---------------------------------------------------
	-- [v1.01.00] Validate Enable Status
	---------------------------------------------------
	InfoPanel.setEnabled = function( enabled )
		if InfoPanel.enabled ~= enabled then
			InfoPanel.enabled = enabled;
			if not enabled then
				local plugin = InfoPanel.plugin;
				if plugin.saved_parent then
					plugin:SetParent( plugin.saved_parent );
				end
			else
				local plugin = child;
				InfoPanel.plugin = plugin;
				if not plugin.saved_parent then
					plugin.saved_parent   = plugin:GetParent();
				end
				plugin:SetParent( InfoPanel.container );				
				plugin:SetFrameStrata( InfoPanel.container:GetFrameStrata() );
				plugin:SetFrameLevel( InfoPanel.container:GetFrameLevel()+1 );
				
				InfoPanel.setAnchors();
				InfoPanel.setBackDrop();
				InfoPanel.setMovable(isMovable);

			end				
		end			
	end

	---------------------------------------------------
	-- [v1.01.00] setSelected routine
	---------------------------------------------------
	InfoPanel.setSelected = function( selected )
		if selected ~= InfoPanel.selected then
			InfoPanel.selected = selected;
			if selected then
			else
			end
		end
	end
	
	return InfoPanel;
end